@@ -6,30 +6,24 @@
 # ---------------------------------------
 
 import logging
+import warnings
 
 import lazyTest
-from lazyTest.file import *
-from lazyTest.base import *
 
 
 class Page(object):
-
     __configFile = "\\pytest.ini"
 
     __section = "pytest"
 
-    def __init__(self, driver: WebOption):
+    def __init__(self, driver: lazyTest.WebOption):
         self.driver = driver
         self.lazyLog = logging.getLogger(self.getClassName())
         self.config = lazyTest.ReadIni(self.GetProjectPath() + self.__configFile)
-        self.lazyLog.info(
-            "元素文件: -> %s" % (
-                    self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
-            )
-        )
-        self.source = GetElementSource(
-            self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
-        )
+        path = self.GetProjectPath() + self.__getFilePath() + self.getClassName() + self.__getSuffix()
+        self.lazyLog.info("元素文件: -> %s" % path)
+        data = lazyTest.ReadYaml(path)
+        self.source = lazyTest.ElementSource(**data)
 
     def __getFilePath(self):
         return self.config.GetIniConfig(self.__section, "elementPath")
@@ -38,7 +32,11 @@ class Page(object):
         return self.config.GetIniConfig(self.__section, "suffix")
 
     def GetElement(self, key: str):
-        return self.source.GetElement(key).Element
+        warnings.warn("请使用新的获取方式:Element",DeprecationWarning)
+        return self.source.GetEle(key)
+
+    def Element(self,key: str):
+        return self.source.GetEle(key)
 
     def GetProjectPath(self) -> str: ...
 
